# Changelog

## `0.1.0`

14 Oct 2019

* First stable release

## `0.1.1`

23 Oct 2019

* Add owner field to various user-specific models for future multi-user support (#107)
* Drop support for movies, digital cameras & filter adapters (#109)
* Roll lightmeter and projector into generic accessories (#109)
* Add patchy support for Kubernetes (#112)

## `0.1.2`

25 Oct 2019

* Run PhotoDB in uwsgi and serve static content
* Reduce Docker image size
* Create various env vars to configure PhotoDB
* Various improvements to Kubernetes manifests

## `0.1.3`

25 Oct 2019

* Add libpq at runtime

## `0.1.4`

25 Oct 2019

* Use correct var for production mode

## `0.1.5`

21 Jan 2020

* Final release of 0.1.x series to validate CI
